@@ -31,6 +31,10 @@ write to the Free Software Foundation, Inc., 59 Temple Place, Suite
 #include FT_FREETYPE_H
 
 #include "config.h"
+#ifdef HAVE_ALLOCA_H
+#include <alloca.h>
+#endif
+
 #include <otf.h>
 
 /* Format MSG by FMT and print the result to the stderr, and exit.  */
