@@ -29,6 +29,9 @@ write to the Free Software Foundation, Inc., 59 Temple Place, Suite
 #include <libgen.h>
 
 #include "config.h"
+#ifdef HAVE_ALLOCA_H
+#include <alloca.h>
+#endif
 
 #ifdef HAVE_X11_XAW_COMMAND_H
 
@@ -85,6 +88,9 @@ XtAppContext context;
    | | idxh[7] glyph[112]  ...    glyph[127]| |
    | |         idxl[0]     ...    idxl[15]  | |
    | +--------------------------------------+ |
+   | +--- script_area (box) ----------------+ |
+   | | script(langsys) DFLT ...             | |
+   | +--------------------------------------+ |
    | +---- uvs_area (box) (optional) -------+ |
    | | uvs[?].w ...                         | |
    | +--------------------------------------+ |
@@ -1252,15 +1258,20 @@ create_otf_script_widgets (Widget prev)
     }
   else
     {
+      Widget box;
+      XtSetArg (arg[0], XtNborderWidth, 0);
+      XtSetArg (arg[1], XtNwidth, render_width - (FONT_WIDTH * 15));
+      XtSetArg (arg[2], XtNorientation, XtorientHorizontal);
+      box = XtCreateManagedWidget ("scritp-list", boxWidgetClass, prev, arg, 2);
       XtSetArg (arg[0], XtNstate, True);
-      w = XtCreateManagedWidget (name, toggleWidgetClass, prev, arg, 1);
+      w = XtCreateManagedWidget (name, toggleWidgetClass, box, arg, 1);
       XtAddCallback (w, XtNcallback, ScriptProc, NULL);
       XtSetArg (arg[0], XtNradioGroup, w);
       for (i = 1; i < n; i++)
 	{
 	  compose_script_langsys (script_langsys[i].script,
 				  script_langsys[i].langsys, name);
-	  w = XtCreateManagedWidget (name, toggleWidgetClass, prev, arg, 1);
+	  w = XtCreateManagedWidget (name, toggleWidgetClass, box, arg, 1);
 	  XtAddCallback (w, XtNcallback, ScriptProc, NULL);
 	}	  
     }
