@@ -29,14 +29,14 @@ extern "C" {
 #endif
 
 /* Version name of this library.  */
-#define LIBOTF_VERSION "0.9.10"
+#define LIBOTF_VERSION "0.9.12"
 
 /* Major version number.  */
 #define LIBOTF_MAJOR_VERSION 0
 /* Minor version number.  */
 #define LIBOTF_MINOR_VERSION 9
 /* Release (i.e. patch level) number.  */
-#define LIBOTF_RELEASE_NUMBER 10
+#define LIBOTF_RELEASE_NUMBER 12
 
 /***
     Table of contents:
@@ -1190,11 +1190,11 @@ extern int OTF_get_features (OTF *otf, int gsubp);
 /***
     Check supported features.
 
-    The OTF_check_features() function checks if or not the OpenType
-    font $OTF has, for $SCRIPT and $LANGUAGE, all features in the
-    array $FEATURES.  The array size is $N_FEATURES.  If $LANGUAGE is
-    zero or $OTF doesn't have LangSys for $SCRIPT, the default LangSys
-    is checked.
+    The OTF_check_features() function checks whether or not the
+    OpenType font $OTF has, for $SCRIPT and $LANGUAGE, all features in
+    the array $FEATURES.  The array size is $N_FEATURES.  If $LANGUAGE
+    is zero or $OTF doesn't have LangSys for $SCRIPT, the default
+    LangSys is checked.
 
     If $OTF has all the features, return 1.  Otherwise, return 0.  If
     an error occurs, return -1, and set the variable OTF_error to
