@@ -1563,7 +1563,7 @@ static int get_class_def_auto (int c)
     = sizeof glyph_class_table / sizeof glyph_class_table[0];
   int low, high, mid;
 
-  if (c >= glyph_class_table[table_size - 1])
+  if (c < 0 || c >= glyph_class_table[table_size - 1])
     return 0;
   low = 0;
   high = table_size - 1;
